# This file has been generated


build_system = 'AppVeyor'
build_id = '33347639'
build_number = '666'
build_version = '1.0.666'
job_id = 'yv4m1noad28fv4j6'
job_url = 'https://ci.appveyor.com/project/KyleAltendorf/pm/build/job/yv4m1noad28fv4j6'
