# This file was automatically generated by sub\epyqlib\epyqlib\cli\generateversion.py
__version_build_time__ = '2020-06-05T19:45:40.533490'

__version__ = '2020.6.1'
__sha__ = '18c7876931cbcf8be454d5bb32620ef3ad21376e'
__revision__ = '18c7876931cbcf8be454d5bb32620ef3ad21376e'
